import { User } from './structures/User';
export interface UnbClientOptions {
    /**
     * The api hostname to use. Defaults to https://unbelievaboat.com/api.
     * @default https://unbelievaboat.com/api
     * @type {string}
     */
    baseURL: string;
    /**
     * The api version to use. Defaults to the latest version.
     * @default 'v1'
     * @type {string}
     */
    version: `v${number}`;
    /**
     * The maximum number of times to retry a request if it's ratelimited. Defaults to 3.
     * @default 3
     * @type {number}
     */
    maxRetries: number;
}
export declare class UnbCLient {
    /**
     * Your api token. You may get one [here](https://unbelievaboat.com/api/docs).
     * @type {String}
     */
    readonly token: string;
    readonly options: UnbClientOptions;
    private readonly requestHandler;
    constructor(
    /**
     * Your api token. You may get one [here](https://unbelievaboat.com/api/docs).
     * @type {String}
     */
    token: string, options?: UnbClientOptions);
    /**
     * Increase or decrease the User's balance by a value given in the params
     * @example
     * <Client>.editUserBalance('123456789012345678', '123456789012345678', {
        reason: '@chikoshidori/unb-api did this.',
        cash: '-100'
    });
    */
    editUserBalance(guildId: string, userId: string, data?: EditUserBalanceData): Promise<User>;
    private _request;
}
export interface EditUserBalanceData {
    /**
     * The amount of cash to add to the user's balance.
     * @type {number}
     */
    cash?: number | string;
    /**
     * The amount of bank to add to the user's balance.
     * @type {number}
     */
    bank?: number | string;
    /**
     * Audit log reason
     * @type {string}
     */
    reason?: string;
}
//# sourceMappingURL=Client.d.ts.map